@@ -14,7 +14,8 @@ except ImportError:
 
 @_return_raster
 def _merge(raster_class, out_file, gdal_driver,
-           sources, bounds, data_type, no_data):
+           sources, bounds, data_type, input_no_data,
+           output_no_data):
     """ Merge multiple raster sources
 
     """
@@ -24,12 +25,13 @@ def _merge(raster_class, out_file, gdal_driver,
         dst_w, dst_s, dst_e, dst_n = bounds
     else:
         # scan input files
-        xs = [item for src in sources for item in src.bounds[0:2]]
-        ys = [item for src in sources for item in src.bounds[2::]]
+        xs = [item for src in sources for item in src.bounds[0::2]]
+        ys = [item for src in sources for item in src.bounds[1::2]]
         dst_w, dst_s, dst_e, dst_n = min(xs), min(ys), max(xs), max(ys)
 
     gdal.Warp(out_file, [src._gdal_dataset for src in sources],
               outputBounds=(dst_w, dst_s, dst_e, dst_n),
               format=gdal_driver.GetDescription(),
-              srcNodata=[src.no_data for src in sources],
-              dstNodata=no_data, outputType=data_type)
+              srcNodata=input_no_data,
+              dstNodata=output_no_data,
+              outputType=data_type)
